#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022/8/25 20:12:59

@author: LiuKuan
@copyright: Apache License, Version 2.0
'''

# ===============================================================================
'''
'''
# ===============================================================================

__all__ = ['show_plt']

def show_plt(img, cmap=None, norm=None, aspect=None, interpolation=None,
        alpha=None, vmin=None, vmax=None, origin=None, extent=None, *,
        interpolation_stage=None, filternorm=True, filterrad=4.0,
        resample=None, url=None, data=None, **kwargs):
    import matplotlib.pyplot as plt
    plt.imshow(img,cmap=cmap, norm=norm, aspect=aspect, interpolation=interpolation,
        alpha=alpha, vmin=vmin, vmax=vmax, origin=origin, extent=extent,
        interpolation_stage=interpolation_stage, filternorm=filternorm, filterrad=filterrad,
        resample=resample, url=url, data=data, **kwargs)
