#! /usr/bin/env python
# -*- coding: utf-8 -*-
'''
Created on 2022.08

@author: laok
@copyright: Apache License, Version 2.0
'''

# ===============================================================================
#                                                                                
# ===============================================================================

import re


class_bin_metric_list = [
    '',


]

def get_class_bin_metric(name):
    pass


class_metric_list = [

]

def get_class_metric_list():
    pass

cluster_metric_list = [


]

def get_cluster_metric(name):
    pass


regress_metric_list = [
    'explained_variance', 'explained_variance_score',
    'max_error',

]

def get_regress_metric(name):
    if name in ['explained_variance', 'explained_variance_score']:
        from sklearn.metrics import explained_variance_score as Alg
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg        
    elif name in [ 'neg_mean_absolute_error', 'mean_absolute_error']:
        from sklearn.metrics import mean_absolute_error as Alg 
    elif name in ['neg_mean_squared_error', 'mean_squared_error']:
        from sklearn.metrics import mean_squared_error as Alg  
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg      
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg  
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg      
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg  
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg      
    elif name == 'max_error':
        from sklearn.metrics import max_error as Alg      
    return Alg


